@@ -9,7 +9,7 @@ from clu.config import abc, ns
 from clu.config.keymaputils import thaw_name, thaw_class, freeze_name, freeze_class
 from clu.constants import consts
 from clu.predicates import tuplize, typeof
-from clu.typology import ismapping
+from clu.typology import ismapping, isset
 from clu.exporting import Exporter, sysmods, itermodule
 
 exporter = Exporter(path=__file__)
@@ -61,26 +61,29 @@ class FrozenFlat(abc.FrozenKeyMap, clu.abstract.ReprWrapper,
             keys are strings; namespaces can be specified per-key as per the
             output of ‘pack_ns(…)’ (q.v. function definition supra.)
         """
-        try:
-            super().__init__(**updates)
-        except TypeError:
-            super().__init__()
+        # Call up:
+        super().__init__(**updates)
+        
+        # Sort out our passed-in dictionary:
         if hasattr(dictionary, 'dictionary'):
             dictionary = getattr(dictionary, 'dictionary')
         elif hasattr(dictionary, 'flatten'):
             dictionary = getattr(dictionary.flatten(), 'dictionary')
+        
+        # Assign things:
         self.dictionary = dict(dictionary or {})
         if updates:
             self.dictionary.update(**updates)
     
     def thaw(self):
-        return thaw_class(type(self))(dictionary=copy.deepcopy(self.dictionary))
+        return thaw_class(type(self))(dictionary=copy.copy(self.dictionary))
     
     def nestify(self, cls=None, walker=flatwalk):
         """ Articulate a flattened KeyMap instance out into one that is nested. """
         if cls is None:
             cls = FrozenNested
-        return cls(tree=articulate(self.dictionary, walker=walker))
+        return cls(tree=articulate(self.dictionary, walker=walker),
+                nskeyset=frozenset(self.keys()))
     
     def __iter__(self):
         yield from self.dictionary
@@ -106,7 +109,7 @@ class FrozenFlat(abc.FrozenKeyMap, clu.abstract.ReprWrapper,
     
     def to_dict(self):
         """ Used by `clu.config.codecs` to serialize the keymap """
-        return copy.deepcopy(self.dictionary)
+        return copy.copy(self.dictionary)
 
 @export
 class Flat(FrozenFlat, abc.KeyMap):
@@ -114,7 +117,7 @@ class Flat(FrozenFlat, abc.KeyMap):
     """ A concrete mutable KeyMap class with a flat internal topology. """
     
     def freeze(self):
-        return freeze_class(type(self))(dictionary=copy.deepcopy(self.dictionary))
+        return freeze_class(type(self))(dictionary=copy.copy(self.dictionary))
     
     def __setitem__(self, nskey, value):
         self.dictionary[nskey] = value
@@ -159,21 +162,30 @@ class FrozenNested(abc.NamespaceWalker, clu.abstract.ReprWrapper,
         or, if you will, a nested – internal topology.
     """
     
-    __slots__ = 'tree'
+    __slots__ = ('tree', 'nskeys')
     
-    def __init__(self, tree=None, **updates):
+    @classmethod
+    def from_dict(cls, instance_dict):
+        """ Used by `clu.config.codecs` to deserialize keymaps """
+        out = cls(nskeyset=instance_dict.get('nskeyset', None))
+        out.tree = instance_dict['tree']
+        return out
+    
+    def __init__(self, tree=None, *, nskeyset=None, **updates):
         """ Initialize an articulated (née “nested”) KeyMap instance from a
             target nested dictionary (or a “tree” of dicts).
         """
-        try:
-            super().__init__(**updates)
-        except TypeError:
-            super().__init__()
+        # Call up:
+        super().__init__()
+        
+        # Sort out the nature of the input:
         if hasattr(tree, 'tree'):
             tree = getattr(tree, 'tree')
         elif hasattr(tree, 'nestify'):
             tree = getattr(tree.nestify(), 'tree')
-        self.tree = dictify(dict(tree or {}), cls=dict)
+        
+        # Assign, and deal with updates:
+        self.tree = dictify(tree or {})
         if updates:
             for nskey, value in updates.items():
                 key, fragments = ns.unpack_ns(nskey)
@@ -185,15 +197,25 @@ class FrozenNested(abc.NamespaceWalker, clu.abstract.ReprWrapper,
                         d[fragment] = {}
                         d = d[fragment]
                 d[key] = value
+        
+        # Keep the keyset we got:
+        self.nskeys = nskeyset and frozenset(nskeyset) or None
     
     def walk(self):
         """ Iteratively walk the nested KeyMap’s tree of dicts. """
         yield from mapwalk(self.tree)
     
-    def thaw(self):
-        return thaw_class(type(self))(tree=copy.deepcopy(self.tree))
+    def nskeyset(self):
+        """ Walk the tree, and assemble a set of the namespaced keys """
+        yield from (ns.pack_ns(key, *fragments) \
+               for *fragments, key, value in self.walk() \
+                   if not ismapping(value))
     
-    def submap(self, *namespaces, unprefixed=False, cls=False):
+    def thaw(self):
+        return thaw_class(type(self))(tree=copy.copy(self.tree),
+                                  nskeyset=copy.copy(self.nskeys))
+    
+    def submap(self, *namespaces, unprefixed=False, cls=None):
         """ Return a flattened mapping, if possible a mutable one,
             containing only items with keys matching the specified
             namespaces (as namespaced:key:paths).
@@ -204,13 +226,14 @@ class FrozenNested(abc.NamespaceWalker, clu.abstract.ReprWrapper,
         
         # Short-circuit for returning unprefixed top-level items:
         if unprefixed:
-            return cls({ key : value for key, value in self.tree.items() \
-                                                    if not ismapping(value) })
+            return cls({ key: value \
+                     for key, value in self.tree.items() \
+                         if not ismapping(value) })
         
         # If it’s not unprefixed, and we have no namespaces,
         # we cough up a new instance with our data:
         if not namespaces:
-            return cls(self.tree)
+            return cls(self.tree, nskeyset=self.nskeys)
         
         # Our namespaces, their output data:
         ours = frozenset(self._get_namespace_foset().things)
@@ -236,30 +259,21 @@ class FrozenNested(abc.NamespaceWalker, clu.abstract.ReprWrapper,
     
     def clone(self, deep=False, memo=None):
         copier = deep and copy.deepcopy or copy.copy
-        return type(self)(tree=copier(self.tree))
+        return type(self)(tree=copier(self.tree),
+                      nskeyset=copier(self.nskeys))
     
     def to_dict(self):
         """ Used by `clu.config.codecs` to serialize the keymap """
-        return copy.deepcopy(self.tree)
+        return { 'tree'     : copy.copy(self.tree),
+                 'nskeyset' : None }
     
     def __contains__(self, nskey):
-        key, fragments = ns.unpack_ns(nskey)
-        if not fragments:
-            # Test for mappings to prevent false positives:
-            return not ismapping(self.tree.get(key, {}))
-        d = self.tree
-        for fragment in fragments:
-            try:
-                d = d[fragment]
-            except KeyError:
-                return False
-        # Test for mappings to prevent false positives:
-        return not ismapping(d.get(key, {}))
+        if not isset(self.nskeys):
+            self.nskeys = frozenset(self.nskeyset())
+        return nskey in self.nskeys
     
     def __getitem__(self, nskey):
         key, fragments = ns.unpack_ns(nskey)
-        if not fragments:
-            return self.tree[key]
         d = self.tree
         for fragment in fragments:
             d = d[fragment]
@@ -272,70 +286,41 @@ class Nested(FrozenNested, abc.KeyMap):
         internal topology.
     """
     
+    def __init__(self, tree=None, *, nskeyset=None, **updates):
+        """ Initialize an articulated (née “nested”) KeyMap instance from a
+            target nested dictionary (or a “tree” of dicts).
+        """
+        # Call up, without passing nskeyset:
+        super().__init__(tree=tree, nskeyset=None, **updates)
+        
+        # Mutable-ize the keyset:
+        self.nskeys = nskeyset and set(nskeyset) or set(self.nskeyset())
+    
     def freeze(self):
-        return freeze_class(type(self))(tree=copy.deepcopy(self.tree))
+        return freeze_class(type(self))(tree=copy.copy(self.tree),
+                                    nskeyset=frozenset(self.nskeys))
     
     def __setitem__(self, nskey, value):
         key, fragments = ns.unpack_ns(nskey)
-        if not fragments:
-            self.tree[key] = value
-        else:
-            d = self.tree
-            for fragment in fragments:
-                try:
-                    d = d[fragment]
-                except KeyError:
-                    d[fragment] = {}
-                    d = d[fragment]
-            d[key] = value
+        d = self.tree
+        for fragment in fragments:
+            try:
+                d = d[fragment]
+            except KeyError:
+                d[fragment] = {}
+                d = d[fragment]
+        d[key] = value
+        self.nskeys.add(nskey)
     
     def __delitem__(self, nskey):
-        if nskey in self:
-            key, fragments = ns.unpack_ns(nskey)
-            if not fragments:
-                del self.tree[key]
-            else:
-                d = self.tree
-                for fragment in fragments:
-                    d = d[fragment]
-                del d[key]
-        else:
+        if nskey not in self:
             raise KeyError(nskey)
-
-@export
-class KeyedAccessor(metaclass=clu.abstract.Slotted):
-    
-    __slots__ = ('keymap', 'namespace')
-    
-    def __init__(self, keymap, namespace=""):
-        ourmap = hasattr(keymap, 'nestify') and keymap.nestify() or keymap
-        cls = type(keymap)
-        self.keymap = cls(ourmap.submap(self.namespace, unprefixed=bool(self.namespace)))
-    
-    def __getattr__(self, key):
-        """ Attribute access repacks the key """
-        nskey = ns.pack_ns(key, *self.namespace)
-        if nskey in self.keymap:
-            return self[nskey]
-        raise AttributeError(f"namespaced key {nskey} not present in keymap")
-    
-    def accessor(self, *addenda):
-        namespace = ns.concatenate_ns(*self.namespace, *addenda)
-        realigned = type(self)(keymap=self.keymap,
-                               namespaces=ns.concatenate_ns(*namespace))
-        return realigned
-    
-    def __contains__(self, nskey):
-        return nskey in self.keymap
-    
-    def __getitem__(self, nskey):
-        """ Unpack and return """
-        *addenda, key = ns.split_ns(nskey)
-        accessor = self.accessor(*addenda)
-        if nskey in accessor.keymap:
-            return accessor.keymap[nskey]
-        if ns.concatenate_ns(*addenda) in set(self.keymap.namespaces()):
-            return accessor
+        key, fragments = ns.unpack_ns(nskey)
+        d = self.tree
+        for fragment in fragments:
+            d = d[fragment]
+        del d[key]
+        self.nskeys.remove(nskey)
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
@@ -433,14 +418,8 @@ def test():
         for meat in fridge:
             pprint(meat)
     
-    @inline
-    def test_mapwalk():
-        """ Simple “mapwalk(…)” content """
-        dictderive = tuple(mapwalk(nestedmaps()))
-        return dictderive
-    
-    @inline
-    def test_mapwalk_content():
+    @inline.precheck
+    def show_mapwalk_content():
         """ Verbose “mapwalk(…)” content check """
         for mappingpath in mapwalk(nestedmaps()):
             *fragments, key, value = mappingpath
@@ -451,6 +430,12 @@ def test():
             print("VALUE:", value)
             print()
     
+    @inline
+    def test_mapwalk():
+        """ Simple “mapwalk(…)” content """
+        dictderive = tuple(mapwalk(nestedmaps()))
+        return dictderive
+    
     @inline
     def test_frozenflat_nested_eq():
         """ FrozenFlat and Nested equivalence """
@@ -465,10 +450,11 @@ def test():
         
         flat = FrozenFlat(flat_dict)
         nested = Nested(flat)
+        flattened = nested.flatten()
         
-        assert nested.flatten() == flat
-        assert nested.flatten().dictionary == flatdict()
-        assert nested.flatten().thaw() == flat
+        assert flattened == flat
+        assert flattened.dictionary == flatdict()
+        assert flattened.thaw() == flat
         
         assert len(flat) == len(nested)
     
@@ -512,15 +498,16 @@ def test():
         for mappingpath in mapwalk(nested.tree):
             *fragments, key, value = mappingpath
             nskey = ns.pack_ns(key, *fragments)
-            assert nskey in nested or nskey in arbitrary()
+            assert nskey in nested
     
     @inline
     def test_frozennested_flat_eq():
         """ FrozenNested and Flat roundtrip commutativity """
         nested = FrozenNested(tree=nestedmaps())
         flat = Flat(nested)
-        assert flat.nestify() == nested
-        assert flat.nestify().thaw() == nested
+        renested = flat.nestify()
+        assert renested == nested
+        assert renested.thaw() == nested
     
     @inline
     def test_nested_frozennested_eq():
